package WebGUI::i18n::German::AuthWebGUI;
use utf8;
our $I18N = {
  1 => {
    'lastUpdated' => '1153201558',
    'message' => 'WebGUI Authentifizierungs-Optionen'
  },
  10 => {
    'lastUpdated' => '1178700851',
    'message' => 'Altes Passwort'
  },
  11 => {
    'lastUpdated' => '1178700862',
    'message' => 'Neues Passwort'
  },
  12 => {
    'lastUpdated' => '1153201591',
    'message' => 'Sie dürfen das alte nicht als das neue Passwort verwenden<br />'
  },
  13 => {
    'lastUpdated' => '1178700870',
    'message' => 'Passwort-Wiederherstellung erlauben?'
  },
  14 => {
    'lastUpdated' => '1178700879',
    'message' => 'Minimale Passwortlänge'
  },
  15 => {
    'lastUpdated' => '1178700886',
    'message' => 'Minimale Passwortlänge'
  },
  '15 help' => {
    'lastUpdated' => '1227567188',
    'message' => 'Minimum Zeichenanzahl im Passwort.'
  },
  16 => {
    'lastUpdated' => '1178700893',
    'message' => 'Passwort Timeout'
  },
  '16 help' => {
    'lastUpdated' => '1227567284',
    'message' => 'Der Passwort-Timeout legt die Gültigkeitsdauer f&uuml;r ein Passwort fest. Nach Ablauf wird der benutzer aufgefordert ein neues Passwort einzugeben.'
  },
  17 => {
    'lastUpdated' => '1178700900',
    'message' => 'Passwort aktualisiert'
  },
  18 => {
    'lastUpdated' => '1153201669',
    'message' => 'Benutzern ermöglichen, das Passwort zu ändern?<br />'
  },
  '18 help' => {
    'lastUpdated' => '1227567405',
    'message' => 'Dürfen Benutzer Ihr Passwort ändern? Achtung: dieses zusammen mit Passwort-Timeouts zu benutzen kann viel Adminsitrationsarbeit erforderlich machen. '
  },
  19 => {
    'lastUpdated' => '1153201689',
    'message' => 'Benutzern erlauben, ihren Benutzernamen zu ändern?<br />'
  },
  '19 help' => {
    'lastUpdated' => '1227567459',
    'message' => 'Dürfen Benutzer die Benutzerkennung ändern?'
  },
  2 => {
    'lastUpdated' => '1178700910',
    'message' => 'Passwort (Bestätigung)'
  },
  20 => {
    'lastUpdated' => '1153201715',
    'message' => 'Benutzern erlauben, das Passwort zu ändern?<br />'
  },
  21 => {
    'lastUpdated' => '1153201737',
    'message' => 'Benutzern erlauben, ihren Benutzernamen zu ändern?<br />'
  },
  22 => {
    'lastUpdated' => '1178700918',
    'message' => 'Es gab nicht zu aktualisieren.'
  },
  3 => {
    'lastUpdated' => '1153201769',
    'message' => 'Ihr Passwort stimmt nicht. Bitte versuchen Sie es noch einmal.<br />'
  },
  4 => {
    'lastUpdated' => '1178700927',
    'message' => 'Ihr Passwort darf nicht leer sein.'
  },
  5 => {
    'lastUpdated' => '1153201795',
    'message' => 'Ihr Passwort darf nicht &quot;password&quot; lauten.<br />'
  },
  6 => {
    'lastUpdated' => '1178700937',
    'message' => 'Passwortwiederherstellung erlauben?'
  },
  7 => {
    'lastUpdated' => '1153201835',
    'message' => 'Passwörter müssen eine Mindestlänge haben von <br />'
  },
  8 => {
    'lastUpdated' => '1153201846',
    'message' => 'Ihr Passwort ist abgelaufen.'
  },
  9 => {
    'lastUpdated' => '1153201873',
    'message' => 'Passwörter sollen bei der Erstellung eines Benutzers ablaufen?<br />'
  },
  '9 help' => {
    'lastUpdated' => '1227567532',
    'message' => 'Diese Angabe macht das Passwort sofort nach der Kontenerstellung ungültig.'
  },
  'Password Recovery Email Template' => {
    'lastUpdated' => '1287563135',
    'message' => 'Passwort-Wiederherstellung, E-Mail-Template'
  },
  'account activation template' => {
    'lastUpdated' => '1287563144',
    'message' => 'E-Mailvorlage Kontoaktivierung'
  },
  'account activation template help' => {
    'lastUpdated' => '1287563152',
    'message' => 'Wählen Sie eine Vorlage für die E-Mail, die an neue Benutzer versendet wird.'
  },
  'account activation template title' => {
    'lastUpdated' => '1287563161',
    'message' => 'WebgGUI Authentifizierung - E-Mail zur Benutzeraktivierung'
  },
  'account deactivate account template title' => {
    'lastUpdated' => '1269422312',
    'message' => 'WebGUI-Authentifizierung Konto deaktivieren Template '
  },
  'account template' => {
    'lastUpdated' => '1178700944',
    'message' => 'Account Template'
  },
  'account template help' => {
    'lastUpdated' => '1227567606',
    'message' => 'Wählen Sie eine Vorlage für die Anzeige des Benutzerkontos'
  },
  'account.form.password' => {
    'lastUpdated' => '1178700964',
    'message' => 'Standard Passwort Formular Feld'
  },
  'account.form.password.label' => {
    'lastUpdated' => '1178700987',
    'message' => 'Standard Text für Passwort Formular Feld.'
  },
  'account.form.passwordConfirm' => {
    'lastUpdated' => '1178701017',
    'message' => 'Standard Passwortbestätigung Formular Feld.'
  },
  'account.form.passwordConfirm.label' => {
    'lastUpdated' => '1178701049',
    'message' => 'Standard Text für Passwortbestätigung Formular Feld.'
  },
  'account.form.username' => {
    'lastUpdated' => '1178701068',
    'message' => 'Standard Benutzername Formular Feld.'
  },
  'account.form.username.label' => {
    'lastUpdated' => '1178701092',
    'message' => 'Standard Text für Benutzername Formular Feld.'
  },
  'account.message' => {
    'lastUpdated' => '1178701138',
    'message' => 'Irgendeine Nachricht, die vom System zurückgegeben wird. Wird normalerweise dargestellt, nachdem das Formular abgeschickt wurde.'
  },
  'account.nofields' => {
    'lastUpdated' => '1178701177',
    'message' => 'Standarddarstellung falls keine darzustellenden Formelemente vorhanden sind.'
  },
  'account.noform' => {
    'lastUpdated' => '1178701222',
    'message' => 'Gibt an, ob das Account Formular irgendwechle sichtbaren Elemente besitzt.'
  },
  'activationUrl' => {
    'lastUpdated' => '1238017323',
    'message' => 'Die URL zur Aktivierung des neu kreierten Kontos'
  },
  'anon reg template title' => {
    'lastUpdated' => '1178701314',
    'message' => 'WebGUI Authentifizierung Anonyme Registrierung Template'
  },
  'anonymousRegistration.isAllowed' => {
    'lastUpdated' => '1178701570',
    'message' => 'Flag, das anzeigt, ob eine anonyme Registrierung erlaubt ist oder nicht.'
  },
  'captcha failure' => {
    'lastUpdated' => '1178701649',
    'message' => 'Sie müssen alle 6 Zeichen eingeben, die auf dem Bild dargestellt sind.'
  },
  'captcha label' => {
    'lastUpdated' => '1217147191',
    'message' => 'Geben Sie die nachfolgende Zeichenfolge ein'
  },
  'check email for validation' => {
    'lastUpdated' => '1287563173',
    'message' => 'Bitte checken Sie Ihre E-Mail, um Ihren Account zu aktivieren.'
  },
  'create account template' => {
    'lastUpdated' => '1178701843',
    'message' => 'Account erzeugen Template'
  },
  'create account template help' => {
    'lastUpdated' => '1227567665',
    'message' => 'Wählen Sie eine Vorlage für den Bildschirm zur Anlage eines Benutzerkontos.'
  },
  'create.form.hidden' => {
    'lastUpdated' => '1178701884',
    'message' => 'Versteckte Formular Felder; Voraussetzung fü das Abschicken des Formulars.'
  },
  'create.form.oldPassword' => {
    'lastUpdated' => '1178701912',
    'message' => 'Standard altes Passwort Formular Feld.'
  },
  'create.form.oldPassword.label' => {
    'lastUpdated' => '1252473975',
    'message' => 'Standard Text für altes Passwort Formular Feld.'
  },
  'create.form.password' => {
    'lastUpdated' => '1178702948',
    'message' => 'Standard Passwort Formular Feld.'
  },
  'create.form.password.label' => {
    'lastUpdated' => '1178702972',
    'message' => 'Standard Text für Passwort Formular Feld.'
  },
  'create.form.passwordConfirm' => {
    'lastUpdated' => '1178703002',
    'message' => 'Standard Passwortbestätigung Formular Feld.'
  },
  'create.form.passwordConfirm.label' => {
    'lastUpdated' => '1178703044',
    'message' => 'Standard Text für Passwortbestätigung Formular Feld.'
  },
  'create.form.username' => {
    'lastUpdated' => '1178703096',
    'message' => 'Standard Benutzername Formular Feld.'
  },
  'create.form.username.label' => {
    'lastUpdated' => '1178703114',
    'message' => 'Standard Text für Benutzername Formular Feld.'
  },
  'create.message' => {
    'lastUpdated' => '1178703233',
    'message' => 'Irgendeine Nachricht, die vom System zurückgeliefert wird. Normalerweise dargestellt nachdem Formular abgeschickt wurde.'
  },
  'createAccount.label' => {
    'lastUpdated' => '1178703267',
    'message' => 'Standard Label für Link zur anonymen Registrierung.'
  },
  'createAccount.url' => {
    'lastUpdated' => '1178703296',
    'message' => 'URL der Seite für anonyme Registrierung'
  },
  'deactivate account template' => {
    'lastUpdated' => '1269422333',
    'message' => 'Konto deaktivieren Template'
  },
  'deactivate account template help' => {
    'lastUpdated' => '1269422408',
    'message' => 'Wählen Sie ein Template um die Seite anzuzeigen, auf der die Nutzer Ihr Konto deaktivieren können.'
  },
  'deactivate account template title' => {
    'lastUpdated' => '1178703367',
    'message' => 'WebGUI Authentifizierung Deaktivierung Account Template'
  },
  'display account template title' => {
    'lastUpdated' => '1178703412',
    'message' => 'WebGUI Authentifizierung Anzeige Account Template'
  },
  'displayTitle' => {
    'lastUpdated' => '1178703427',
    'message' => 'Standard Seitentitel.'
  },
  'email address validation email body' => {
    'lastUpdated' => '1244063441',
    'message' => 'Willkommen auf unserer Seite. 
Bitte klicken Sie auf den folgenden Link oder übernehmen Sie den Link in Ihren Browser, um ihren Account zu aktivieren.

Danach können Sie sich mit Ihrer Kennung und dem Passwort anmelden.


'
  },
  'email address validation email subject' => {
    'lastUpdated' => '1178703482',
    'message' => 'Account Aktivierung'
  },
  'email password recovery end message' => {
    'lastUpdated' => '1192977767',
    'message' => 'Geben Sie ein neues Kennwort auf Ihren Account unten ein.'
  },
  'email recover password finish message' => {
    'lastUpdated' => '1287563192',
    'message' => 'Eine E-Mail mit einer Anleitung zur Änderung des Passwort wurde verschickt.'
  },
  'email recover password finish message1' => {
    'lastUpdated' => '1192977827',
    'message' => 'Eine E-Mail ist versendet worden'
  },
  'email recover password finish message2' => {
    'lastUpdated' => '1192977909',
    'message' => 'Mit Instruktionen, um Ihr Passwort zurück zu setzen.'
  },
  'email recover password start message' => {
    'lastUpdated' => '1192977996',
    'message' => 'Geben Sie entweder Ihre E-Mail-Adresse oder Ihre Anmeldung unten ein, um das Passwort zurücksetzen zu können.'
  },
  'email validation confirmed' => {
    'lastUpdated' => '1252480610',
    'message' => 'Herzlichen Dank für die Aktivierung Ihres Benutzerkontos.<p />
Sie können sich jetzt mit Ihrer Kennung und Ihrem Passwort anmelden.'
  },
  'error password nonWordCharacters' => {
    'lastUpdated' => '1200441260',
    'message' => 'Das Passwort muss mindestens %s Sonderzeichen (z.B. \'!\',\'@\',\'$\') enthalten.'
  },
  'error password requiredDigits' => {
    'lastUpdated' => '1200441286',
    'message' => 'Das Passwort muss mindestens %s Zahlen enthalten.'
  },
  'error password requiredMixedCase' => {
    'lastUpdated' => '1200441341',
    'message' => 'Das Passwort muss mindestens %s Großbuchstaben und mindestens einen Kleinbuchstaben enthalten.'
  },
  'error passwordRecoveryType no profile fields required' => {
    'lastUpdated' => '1228690885',
    'message' => 'Passwort-Wiederherstellung bei WegGUI-Authentifizierung mittels Profil-Feldern kann nicht aktiviert werden: Es sind keine Benutzer-Profilfelder zur Passwortwiederherstellung nötig.'
  },
  'expired password template' => {
    'lastUpdated' => '1178703499',
    'message' => 'Abgelaufenes Passwort Template'
  },
  'expired password template help' => {
    'lastUpdated' => '1228690992',
    'message' => 'Wählen Sie die Vorlage für die Seite aus, die dem Benutzer angezeigt wird, auf der er ein neues Passwort eingeben kann, wenn das bisherige abgelaufen ist.'
  },
  'expired template title' => {
    'lastUpdated' => '1178703559',
    'message' => 'WebGUI Authentifizierung Passwort Ablauf Template'
  },
  'expired.form.footer' => {
    'lastUpdated' => '1178703680',
    'message' => 'Die benötigten Formular Elemente, die nach dem Passwort Ablauf Formular kommen.'
  },
  'expired.form.header' => {
    'lastUpdated' => '1178703722',
    'message' => 'Die benötigten Formular Elemente, die am Anfang der Passwort Ablauf Seite stehen.'
  },
  'expired.form.hidden' => {
    'lastUpdated' => '1178703773',
    'message' => 'Versteckte Formular Felder die für das Abschicken des Formulars benötigt werden.'
  },
  'expired.form.password' => {
    'lastUpdated' => '1178703787',
    'message' => 'Standard Passwort Formular Feld.'
  },
  'expired.form.password.label' => {
    'lastUpdated' => '1178703811',
    'message' => 'Standard Text für das Passwort Formular Feld.'
  },
  'expired.form.passwordConfirm' => {
    'lastUpdated' => '1178703833',
    'message' => 'Standard Passwortbestätigung Formular Feld.'
  },
  'expired.form.passwordConfirm.label' => {
    'lastUpdated' => '1178703863',
    'message' => 'Standard Text für Passwortbestätigung Formular Feld'
  },
  'expired.form.submit' => {
    'lastUpdated' => '1178703907',
    'message' => 'Die Standard Submit Schaltfläche für das Passwort Ablauf Formular.'
  },
  'expired.message' => {
    'lastUpdated' => '1178703947',
    'message' => 'Irgendeine Nachricht, die vom System zurückgeliefert wird. Normalerweise dargestellt nachdem Formular abgeschickt wurde.'
  },
  'login template' => {
    'lastUpdated' => '1178703958',
    'message' => 'Login Template'
  },
  'login template help' => {
    'lastUpdated' => '1228690696',
    'message' => 'Wählen Sie eine Vorlage für die Seite aus, auf der der Benutzer sich einloggen kann. Diese ist unterschiedlich zu allen Makros, die dem Benutzer ebenfalls Log-In-Formulare anzeigen.'
  },
  'login template title' => {
    'lastUpdated' => '1178704015',
    'message' => 'WebGUI Authentifizierung Login Template'
  },
  'login.form.email' => {
    'lastUpdated' => '1287563217',
    'message' => 'Standard E-Mail Formular Feld.'
  },
  'login.form.email.label' => {
    'lastUpdated' => '1287563239',
    'message' => 'Standard Text für E-Mail Formular Feld'
  },
  'login.label' => {
    'lastUpdated' => '1178704071',
    'message' => 'Standard Text Label für Link zur Login Seite.'
  },
  'login.message' => {
    'lastUpdated' => '1178704087',
    'message' => 'Irgendeine Nachricht, die vom System zurückgeliefert wird. Normalerweise dargestellt nachdem Formular abgeschickt wurde.'
  },
  'login.url' => {
    'lastUpdated' => '1178704098',
    'message' => 'URL zur Login Seite.'
  },
  'new password help' => {
    'lastUpdated' => '1200441368',
    'message' => 'Bitte neues Passwort hier eingeben'
  },
  'new password label' => {
    'lastUpdated' => '1200441380',
    'message' => 'Neues Passwort'
  },
  'new password verify' => {
    'lastUpdated' => '1200441392',
    'message' => 'Neues Passwort bestätigen'
  },
  'new password verify help' => {
    'lastUpdated' => '1200441416',
    'message' => 'Passwort erneut zur Bestätigung eingeben'
  },
  'newUser_password' => {
    'lastUpdated' => '1238250365',
    'message' => 'Das Passwort für das neu kreierte Konto'
  },
  'newUser_username' => {
    'lastUpdated' => '1238017346',
    'message' => 'Name des neuen Benutzers'
  },
  'no email address' => {
    'lastUpdated' => '1229992309',
    'message' => 'Für diesen Accout ist keine E-Mail-Adresse angegeben. Die Funktion &quot;Passwort-Wiederherstellung per E-Mail&quot; ist nicht möglich.'
  },
  'no registration hack' => {
    'lastUpdated' => '1178704168',
    'message' => 'schließe anonyme Registrierung durch Aufruf von createAccountSave direkt durch die URL ab'
  },
  'password recovery disabled' => {
    'lastUpdated' => '1228690596',
    'message' => 'Ihr Account wurde gesperrt. Sie können kein neues Passwort anfordern, bis Ihr Accout wieder aktiviert wurde.'
  },
  'password recovery email hoverHelp' => {
    'lastUpdated' => '1200441452',
    'message' => 'E-Mail-Adresse hier eingeben'
  },
  'password recovery email label' => {
    'lastUpdated' => '1200441458',
    'message' => 'E-Mail-Adresse'
  },
  'password recovery email template help' => {
    'lastUpdated' => '1287563308',
    'message' => 'Wählen Sie ein Template zur Formatierung der E-Mails für die Passwort-Wiederherstellung.'
  },
  'password recovery login hoverHelp' => {
    'lastUpdated' => '1200441468',
    'message' => 'Benutzernamen hier eingeben'
  },
  'password recovery login label' => {
    'lastUpdated' => '1200441475',
    'message' => 'Benutzername'
  },
  'password recovery multiple results' => {
    'lastUpdated' => '1178704234',
    'message' => 'Sorry, Sie können keine Passwortwiederherstellung für diesen Account durchf&uuml;hren. Bitte kontaktieren Sie einen Administrator. '
  },
  'password recovery no results' => {
    'lastUpdated' => '1244063474',
    'message' => 'Keine Benutzer wurden gefunden, deren Profil passt. Bitte versuchen Sie es erneut.'
  },
  'password recovery no username' => {
    'lastUpdated' => '1178704316',
    'message' => 'Passwortwiederherstellung setzt einen Benutzernamen voraus.'
  },
  'password recovery template' => {
    'lastUpdated' => '1178704331',
    'message' => 'Passwortwiederherstellung Template'
  },
  'password recovery template help' => {
    'lastUpdated' => '1228691003',
    'message' => 'Wählen Sie die Vorlage für die Seite aus, die dem Benutzer angezeigt wird, auf der er ein verlorendes Passwort wiederherstellen kann.'
  },
  'recover password banner' => {
    'lastUpdated' => '1225317250',
    'message' => 'Wiederherstellung Passwort'
  },
  'recover password email text1' => {
    'lastUpdated' => '1225317402',
    'message' => 'Wir erhielten Ihren Antrag zur Änderung des Passworts von &nbsp; '
  },
  'recover password email text2' => {
    'lastUpdated' => '1225317578',
    'message' => 'Bitte benutzen Sie den angegebenen Link um Ihr Passwort zu ändern.'
  },
  'recover password email text3' => {
    'lastUpdated' => '1228691066',
    'message' => 'Wenn Sie keine Passwort-Wiederherstellung beantragt haben, informieren Sie bitte den System-Administrator '
  },
  'recover password not found' => {
    'lastUpdated' => '1225317536',
    'message' => 'Wir haben keinen Benutzer, auf den Ihre Information zutrifft.'
  },
  'recover.form.footer' => {
    'lastUpdated' => '1178704372',
    'message' => 'Die benötigten Formular Elemente, die nach dem Passwortwiederherstellung Formular kommen.'
  },
  'recover.form.header' => {
    'lastUpdated' => '1178704403',
    'message' => 'Die benötigten Formular Elemente, die am Anfang der Passwortwiederherstellung Seite stehen.'
  },
  'recover.form.hidden' => {
    'lastUpdated' => '1178704428',
    'message' => 'Versteckte Formular Felder die für das Abschicken des Formulars benötigt werden.'
  },
  'recover.form.submit' => {
    'lastUpdated' => '1178704472',
    'message' => 'Standard Submit Schaltfläche für das Passwortwiederherstellung Formular.'
  },
  'recover.message' => {
    'lastUpdated' => '1178704487',
    'message' => 'Irgendeine Nachricht, die vom System zurückgeliefert wird. Normalerweise dargestellt nachdem Formular abgeschickt wurde.'
  },
  'recoverFormProfile' => {
    'lastUpdated' => '1178704526',
    'message' => 'Iteriere über die Profilfelder, die f&uuml;r Passwortwiederherstellung nötig sind.'
  },
  'recoverFormProfile formElement' => {
    'lastUpdated' => '1178704566',
    'message' => 'Ein Formular Element für das Profil Feld.'
  },
  'recoverFormProfile id' => {
    'lastUpdated' => '1178704600',
    'message' => 'Die ID des Profilfelds.'
  },
  'recoverFormProfile label' => {
    'lastUpdated' => '1178704616',
    'message' => 'Das Label für das Profilfeld.'
  },
  'recoverFormUsername' => {
    'lastUpdated' => '1178704648',
    'message' => 'Benutzername Formular Feld für die Passwortwiederherstellung.'
  },
  'recoverFormUsernameLabel' => {
    'lastUpdated' => '1178704676',
    'message' => 'Label für das Benutzername Formular Feld f&uuml;r die Passwortwiederherstellung.'
  },
  'recoverPassword.isAllowed' => {
    'lastUpdated' => '1178704707',
    'message' => 'Flag, das angibt, ob die Passwortwiederherstellung aktiviert ist oder nicht.'
  },
  'recoverPassword.label' => {
    'lastUpdated' => '1178704729',
    'message' => 'Standard Label für den Link zur Passwortwiederherstellung.'
  },
  'recoverPassword.url' => {
    'lastUpdated' => '1178704750',
    'message' => 'URL der Passwortwiederherstellungsseite.'
  },
  'recoverPasswordUrl' => {
    'lastUpdated' => '1287563351',
    'message' => 'URL zur Funktion Passwort-Zurücksetzung'
  },
  'recovery email template title' => {
    'lastUpdated' => '1287563391',
    'message' => 'WebGUI Authentication Passwort-Wiederherstellung, E-Mail-Template'
  },
  'recovery template title' => {
    'lastUpdated' => '1178704797',
    'message' => 'WebGUI Authentifizierung Passwortwiederherstellung Template'
  },
  'require username for password recovery' => {
    'lastUpdated' => '1178704825',
    'message' => 'Ist Benutzername für Passwortwiederherstellung erforderlich?'
  },
  'setting passwordRecoveryType email' => {
    'lastUpdated' => '1228691104',
    'message' => 'E-Mail-Adresse'
  },
  'setting passwordRecoveryType none' => {
    'lastUpdated' => '1228691111',
    'message' => 'Nein'
  },
  'setting passwordRecoveryType profile' => {
    'lastUpdated' => '1228691120',
    'message' => 'Profil-Feld'
  },
  'setting webguiNonWordCharacters' => {
    'lastUpdated' => '1277707130',
    'message' => 'Anzahl der verlangten Nicht-Buchstaben-Zeichen in einem Passwort.'
  },
  'setting webguiNonWordCharacters help' => {
    'lastUpdated' => '1228691208',
    'message' => 'Die Anzahl der Nicht-Buchstaben-Zeichen, wie z.B. Interpunktionszeichen, die in einem Benutzerpasswort verpflichtend sind.'
  },
  'setting webguiRequiredDigits' => {
    'lastUpdated' => '1228691236',
    'message' => 'Anzahl der Ziffern in einem Passwort'
  },
  'setting webguiRequiredDigits help' => {
    'lastUpdated' => '1228691263',
    'message' => 'Wie viele Ziffern/Nummern sind in einem Benutzer-Passwort verpflichtend?'
  },
  'setting webguiRequiredMixedCase' => {
    'lastUpdated' => '1228691290',
    'message' => 'Anzahl der Großbuchsteben in einem Benutzerpasswort.'
  },
  'setting webguiRequiredMixedCase help' => {
    'lastUpdated' => '1228691341',
    'message' => 'Diese Einstellung erfodert das Vorkommen von Großbuchstaben in einem Benutzerpasswort. Dadurch sind noch keine Kleinbuchstaben verpflichtend.'
  },
  'subtitle' => {
    'lastUpdated' => '1228690528',
    'message' => 'Besondere Anweisungen für das Formular. Muss nicht bei allen Arten der Passwort-Wiederherstellungs-Vorlagen definiert sein. '
  },
  'title' => {
    'lastUpdated' => '1178704838',
    'message' => 'Standard Seitentitel.'
  },
  'token already used' => {
    'lastUpdated' => '1225317217',
    'message' => 'Dieses Paswort-Authentisierungszeichen wurde bereits verwendet'
  },
  'topicName' => {
    'lastUpdated' => '1178704851',
    'message' => 'WebGUI Authentifizierung'
  },
  'use captcha' => {
    'lastUpdated' => '1178704863',
    'message' => 'Captcha Bild benutzen?'
  },
  'use captcha help' => {
    'lastUpdated' => '1252474167',
    'message' => 'Wenn aktiviert, muss ein Besucher zur Anlage eines Benutzerkontos ein Captcha-Feld ausfüllen. '
  },
  'use email as username description' => {
    'lastUpdated' => '1243495928',
    'message' => 'Wenn "ja", wird die Registrierungsmaske keinen Benutzernamen abfragen. Die E-Mailadresse wird dann als Beutzername registriert.'
  },
  'use email as username label' => {
    'lastUpdated' => '1243495915',
    'message' => 'E-Mail als Benutzername verwenden'
  },
  'validate email' => {
    'lastUpdated' => '1178704875',
    'message' => 'Email Adresse verifizieren?'
  },
  'validate email help' => {
    'lastUpdated' => '1252474119',
    'message' => 'Soll WebGUI eine extra E-Mail mit Link zur Account-Aktivierung an diese Person senden, unabhängig von der Willkommens-E-Mail? Der Benutzeraccount wird nicht aktiviert bevor dieser Link nicht besucht wurde. Nicht best&auml;tigte Accounts verfallen nach einer einstellbaren Zeit. Diese Verfallszeit wird in einem Workflow festgelegt.'
  },
  'webguiPasswordRecovery hoverHelp' => {
    'lastUpdated' => '1225317031',
    'message' => '<p>Wählen Sie &quot;Ja&quot;, um Benutzern, die eine bestimmte Kombination ihrer Profil Felder kennen, die Passwortwiederherstellung zu erlauben. Voraussetzung ist, dass mindestens ein Profil Feld das Flag &quot;Voraussetzung für Passwortwiederhestellung&quot; gesetzt hat. Es wird empfohlen, mehrere Felder zu w&auml;hlen, weil die Passwortwiederherstellung mit nur einem Feld sehr unsicher ist. Bedenken Sie, dass jemand, der alle dieser Felder eines Benutzers kennt, dessen Passwort zur&uuml;cksetzen kann. </p>'
  },
  'webguiPasswordRecoveryRequireUsername hoverHelp' => {
    'lastUpdated' => '1178707164',
    'message' => '<p>Wählen Sie hier &quot;Ja&quot;, wenn Sie wollen, dass die Benutzer ihre Benutzername für die Passwortwiederherstellung eingeben m&uuml;ssen. Andernfalls können Benutzer ihr Passwort zur&uuml;cksetzen bzw. sich im System anmelden, falls Sie nur die anderen Profil Felder kennen, die f&uuml;r die&nbsp; Passwortwiederherstellung wichtig sind. Auch wenn die Benutzern ihren Benuzternamen vergesssen haben. </p>'
  },
  'welcome message template' => {
    'lastUpdated' => '1238250396',
    'message' => 'Vorlage Willkommensnachricht'
  },
  'welcome message template help' => {
    'lastUpdated' => '1238250455',
    'message' => 'Selektieren Sie eine Vorlage für die Willkommensnachricht, die an neue Benutzer gesendet wird.'
  },
  'welcome message template title' => {
    'lastUpdated' => '1238250507',
    'message' => 'WebGUI Authentifizierung Vorlage Willkommensnachricht'
  },
  'welcomeMessage' => {
    'lastUpdated' => '1238256874',
    'message' => 'Willkommensnachricht wie definiert in den Voreinstellungen'
  }
}
;

1;
